@@ -2,10 +2,11 @@
 
 
 CDMEAN2 <-
-  function(Train,Test, P, lambda=1e-5){
+  function(Train,Test, P, lambda=1e-5, C=NULL){
     PTrain<-P[rownames(P)%in%Train,]
     PTest<-P[rownames(P)%in%Test,]
-    CD<-PTest%*%solve(crossprod(PTrain)+lambda*diag(ncol(P)),t(PTrain))
+    if (!is.null(C)){PTest<-C%*%PTest}
+    CD<-PTest%*%solve(crossprod(PTrain)+lambda*diag(ncol(PTrain)),t(PTrain))
     CDmean<-mean(diag(tcrossprod(CD))/diag(tcrossprod(PTest)))
     return(CDmean)
   }
