@@ -2,10 +2,11 @@
 
 #correct version but very close to the previous one. 
 PEVMEAN2 <-
-  function(Train,Test, P, lambda=1e-5){
+  function(Train,Test, P, lambda=1e-5, C=NULL){
     PTrain<-P[rownames(P)%in%Train,]
     PTest<-P[rownames(P)%in%Test,]
-    PEV<-PTest%*%solve(crossprod(PTrain)+lambda*diag(ncol(P)),t(PTrain))
+    if (!is.null(C)){ PTest<-C%*%PTest}
+    PEV<-PTest%*%solve(crossprod(PTrain)+lambda*diag(ncol(PTrain)),t(PTrain))
     PEVmean<-mean(diag(tcrossprod(PEV)))
     return(PEVmean)
   }
